require "./lib/sylfy.rb"
require "test/unit"


class TestKEGGREST < Test::Unit::TestCase
    
    def test_list
        assert_nothing_thrown("pathway") {Sylfy::Service::KEGGREST::list("pathway")}
        assert_nothing_thrown("pathway/hsa") {Sylfy::Service::KEGGREST::list("pathway/hsa")}
        assert_nothing_thrown("organism") {Sylfy::Service::KEGGREST::list("organism")}
        assert_nothing_thrown("hsa") {Sylfy::Service::KEGGREST::list("hsa")}
        assert_nothing_thrown("T01001") {Sylfy::Service::KEGGREST::list("T01001")}
        assert_nothing_thrown("hsa:10458+ece:Z5100") {Sylfy::Service::KEGGREST::list("hsa:10458+ece:Z5100")}
        assert_nothing_thrown("cpd:C01290+gl:G00092") {Sylfy::Service::KEGGREST::list("cpd:C01290+gl:G00092")}
        assert_nothing_thrown("C01290+G00092") {Sylfy::Service::KEGGREST::list("C01290+G00092")}
    end
    
    def test_find
        assert_nothing_thrown("") {Sylfy::Service::KEGGREST::find("genes", "shiga+toxin")}
        assert_nothing_thrown("") {Sylfy::Service::KEGGREST::find("genes", '"shiga toxin"')}
        assert_nothing_thrown("") {Sylfy::Service::KEGGREST::find("compound", "C7H10O5", "formula")}
        assert_nothing_thrown("") {Sylfy::Service::KEGGREST::find("compound", "O5C7", "formula")}
        assert_nothing_thrown("") {Sylfy::Service::KEGGREST::find("compound", "174.05", "exact_mass")}
        assert_nothing_thrown("") {Sylfy::Service::KEGGREST::find("compound", "300-310", "mol_weight")}
    end
    
    def test_get
        assert_nothing_thrown("cpd:C01290+gl:G00092	") {Sylfy::Service::KEGGREST::get("cpd:C01290+gl:G00092")}
        assert_nothing_thrown("C01290+G00092") {Sylfy::Service::KEGGREST::get("C01290+G00092")}
        assert_nothing_thrown("hsa:10458+ece:Z5100") {Sylfy::Service::KEGGREST::get("hsa:10458+ece:Z5100")}
        assert_nothing_thrown("hsa:10458+ece:Z5100/aaseq") {Sylfy::Service::KEGGREST::get("hsa:10458+ece:Z5100", "aaseq")}
        assert_nothing_thrown("hsa05130/kgml") {Sylfy::Service::KEGGREST::get("hsa05130", "kgml")}
    end

    def test_conv
        assert_nothing_thrown("eco/ncbi-geneid") {Sylfy::Service::KEGGREST::conv("eco", "ncbi-geneid")}
        assert_nothing_thrown("ncbi-geneid/eco") {Sylfy::Service::KEGGREST::conv("ncbi-geneid", "eco")}
        assert_nothing_thrown("ncbi-gi/hsa:10458+ece:Z5100") {Sylfy::Service::KEGGREST::conv("ncbi-gi", "hsa:10458+ece:Z5100")}
        assert_nothing_thrown("genes/ncbi-gi:3113320") {Sylfy::Service::KEGGREST::conv("genes", "ncbi-gi:3113320")}
    end
    
    def test_link
        assert_nothing_thrown("pathway/hsa") {Sylfy::Service::KEGGREST::link("pathway", "hsa")}
        assert_nothing_thrown("hsa/pathway") {Sylfy::Service::KEGGREST::link("hsa", "pathway")}
        assert_nothing_thrown("pathway/hsa:10458+ece:Z5100") {Sylfy::Service::KEGGREST::link("pathway", "hsa:10458+ece:Z5100")}
        assert_nothing_thrown("genes/K00500") {Sylfy::Service::KEGGREST::link("genes", "K00500")}
        assert_nothing_thrown("genes/hsa00010") {Sylfy::Service::KEGGREST::link("genes", "hsa00010")}
        assert_nothing_thrown("hsa/hsa00010") {Sylfy::Service::KEGGREST::link("hsa", "hsa00010")}
        assert_nothing_thrown("ko/map00010") {Sylfy::Service::KEGGREST::link("ko", "map00010")}
        assert_nothing_thrown("ko/ko00010") {Sylfy::Service::KEGGREST::link("ko", "ko00010")}
        assert_nothing_thrown("rn/map00010") {Sylfy::Service::KEGGREST::link("rn", "map00010")}
        assert_nothing_thrown("rn/rn00010") {Sylfy::Service::KEGGREST::link("rn", "rn00010")}
        assert_nothing_thrown("ec/map00010") {Sylfy::Service::KEGGREST::link("ec", "map00010")}
        assert_nothing_thrown("ec/ec00010") {Sylfy::Service::KEGGREST::link("ec", "ec00010")}
        assert_nothing_thrown("cpd/map00010") {Sylfy::Service::KEGGREST::link("cpd", "map00010")}
    end
    
end